==> dependency-check-utils-3.1.1-sources.jar: org/owasp/dependencycheck/utils/URLConnectionFailureException.java <==
/*
 * This file is part of dependency-check-core.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Copyright (c) 2014 Jeremy Long. All Rights Reserved.
 */
package org.owasp.dependencycheck.utils;

import java.io.IOException;

/**
 * An exception used when the creation of an URLConnection fails.
 *
 * @author Jeremy Long
 */
public class URLConnectionFailureException extends IOException {

    /**
     * The serial version UID.
     */
    private static final long serialVersionUID = 1L;

    /**
     * Creates a new URLConnectionFailureException.
     */
    public URLConnectionFailureException() {
        super();
    }

    /**
     * Creates a new URLConnectionFailureException.
     *
     * @param msg a message for the exception.
     */
    public URLConnectionFailureException(String msg) {
        super(msg);
    }

    /**
     * Creates a new URLConnectionFailureException.
     *
     * @param ex the cause of the download failure.
     */
    public URLConnectionFailureException(Throwable ex) {
        super(ex);
    }

    /**
     * Creates a new URLConnectionFailureException.
     *
     * @param msg a message for the exception.
     * @param ex the cause of the download failure.
     */
    public URLConnectionFailureException(String msg, Throwable ex) {
        super(msg, ex);
    }
}

==> dependency-check-utils-10.0.0-sources.jar: org/owasp/dependencycheck/utils/URLConnectionFailureException.java <==
/*
 * This file is part of dependency-check-utils.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Copyright (c) 2014 Jeremy Long. All Rights Reserved.
 */
package org.owasp.dependencycheck.utils;

import java.io.IOException;

/**
 * An exception used when the creation of an URLConnection fails.
 *
 * @author Jeremy Long
 * @version $Id: $Id
 */
public class URLConnectionFailureException extends IOException {

    /**
     * The serial version UID for serialization.
     */
    private static final long serialVersionUID = -5899631979662570824L;

    /**
     * Creates a new URLConnectionFailureException.
     */
    public URLConnectionFailureException() {
        super();
    }

    /**
     * Creates a new URLConnectionFailureException.
     *
     * @param msg a message for the exception.
     */
    public URLConnectionFailureException(String msg) {
        super(msg);
    }

    /**
     * Creates a new URLConnectionFailureException.
     *
     * @param ex the cause of the download failure.
     */
    public URLConnectionFailureException(Throwable ex) {
        super(ex);
    }

    /**
     * Creates a new URLConnectionFailureException.
     *
     * @param msg a message for the exception.
     * @param ex the cause of the download failure.
     */
    public URLConnectionFailureException(String msg, Throwable ex) {
        super(msg, ex);
    }
}
